#include "LPD8806_kopterlight.h"
#include "SPI.h"

/*****************************************************************************/
// Kopter light control on LPD8806-based RGB LED Modules in a strip!
/*****************************************************************************/

/*****************************************************************************/
// To be changed according to your setup 
// The LED strips are 40 LEDs per meter but you can extend/cut the strip

#define rigger 1  // number of rigger (default: 4)
#define riggerSize  520  // Pixels / LEDs per rigger  (default: 10)
#define stripSize (riggerSize*rigger)

// define variables for spectrum analyser
int analogPinA = 0; // read from multiplexer (Channel A) using analog input 0
int analogPinB = 1; // read from multiplexer (Channel B) using analog input 1
int strobePin = 4; // strobe is attached to digital pin 4
int resetPin = 5; // reset is attached to digital pin 5

int spectrumValueA[7]; // to hold a2d values (default 7)
int spectrumValueB[7]; // to hold a2d values (default 7)
int Colour_A[7]; // Colour Value of Spectum
int Colour_B[7]; // Colour Value of Spectum
int Rigger_max_A[7]; // Max No of LED lighted in Spectum
int Rigger_max_B[7]; // Max NO of LED lighted in Spectum

// Use only if Hardware SPI is not possible
// int dataPin = 3;        // Software SPI Data Pin
// int clockPin = 2;       // Software SPI Clock Pin
// Soft SPI
// LPD8806 strip = LPD8806(stripSize, dataPin, clockPin, rigger);

// HW SPI
// on Arduino 168/328 thats data = 11, and clock = pin 13
LPD8806 strip = LPD8806(stripSize, rigger);

/*****************************************************************************/
//Do not change or remove these!
void setup() {
  
  // Definition of Input and Output Pins for Spectrum analyser
  pinMode(analogPinA, INPUT);
  pinMode(analogPinB, INPUT);
  pinMode(strobePin, OUTPUT);
  pinMode(resetPin, OUTPUT);
  analogReference(DEFAULT); // defines the reference voltage used for analog input
  digitalWrite(resetPin, LOW);
  digitalWrite(strobePin, HIGH);
  
  // Start up the LED strip
  strip.begin();
  // Update the strip, to start they are all 'off'
  strip.show();
 }

/*****************************************************************************/
//                       Space for your light effects:
/*****************************************************************************/
// Only inside Void Loop() you are allowed to design your light effects !!
// ( If you like to program a new pattern or sequences, refer to sequences.ino)
/*****************************************************************************/
// Parameter: Colors are defined by the additive RGB color model. 
//            n = LED No on rigger 
//            r = red    ( max. 128)
//            g = green  ( max. 128)
//            b = blue   ( max. 128)
//            dly = delay ( typical: 10 - 50 ) 
//            cyl = cyles ( how many times this sequence will repeat )
//            riX = rigger to set pixel / to show sequence on x= number of  rigger
/*****************************************************************************/
void loop() {
 
 clearstrip ();
 
 for (int i = 0; i < 7; i++) // (default i < 7)
   {
   digitalWrite(strobePin, LOW);
   delayMicroseconds(30); // to allow the output to settle
   
 //  Channel A (uses half of the defined stripe length to display the 7 spectra)
   spectrumValueA[i] = analogRead(analogPinA);
   Colour_A[i] = map(spectrumValueA[i], 0, 1023, 0, 384);
   Rigger_max_A[i] = map(spectrumValueA[i], 40, 1023, 0, riggerSize/7/2);
   
   for (int j=i*riggerSize/14; j < i*riggerSize/14+Rigger_max_A[i]; j++) {
     strip.setPixelColor(j, Wheel(Colour_A[i]),1,0,0,0,0,0,0,0);
     }
   
 // Channel B (uses the other half of the defined stripe length to display the 7 spectra)
   spectrumValueB[i] = analogRead(analogPinB);  
   Colour_B[i] = map(spectrumValueB[i], 0, 1023, 0, 384);
   Rigger_max_B[i] = map(spectrumValueB[i], 40, 1023, 0, riggerSize/7/2);
   
   for (int j=riggerSize-i*riggerSize/14-1; j > riggerSize-i*riggerSize/14-Rigger_max_B[i]-1; j--) {
     strip.setPixelColor(j, Wheel(Colour_B[i]),1,0,0,0,0,0,0,0);
     }

   digitalWrite(strobePin, HIGH);
   }
   strip.show();
 
}


